@@ -11,9 +11,6 @@
 #include <KLocalizedString>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KDBusService>
 
 #include "ksquareswindow.h"
@@ -24,17 +21,8 @@
 
 int main(int argc, char **argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("ksquares"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("ksquaresrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("ksquaresui.rc"));
-    migrate.migrate();
-#endif
+
     KLocalizedString::setApplicationDomain("ksquares");
     KAboutData about(QStringLiteral("ksquares"), i18n("KSquares"),
                      QStringLiteral(KSQUARES_VERSION_STRING),
@@ -47,20 +35,22 @@ int main(int argc, char **argv)
     about.addCredit(i18n("Fela Winkelmolen"), i18n("Many patches and bugfixes"));
     about.addCredit(i18n("Tom Vincent Peters"), i18n("Hard AI"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(about);
-    KCrash::initialize();
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
 
+    KCrash::initialize();
+
+    QCommandLineParser parser;
+    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
+
     KDBusService service;
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("ksquares")));
 
     // default names for players
-    KConfigGroup cg(KSharedConfig::openConfig(), "General");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("General"));
     if (cg.readEntry<bool>("initializeNames", true)) {
         QStringList playerNames;
         playerNames << KUser().property(KUser::FullName).toString();
